# RADICAL-Analytics (RA)

[![Build Status](https://github.com/radical-cybertools/radical.analytics/actions/workflows/python-app.yml/badge.svg)](https://github.com/radical-cybertools/radical.analytics/actions/workflows/python-app.yml)
[![codecov](https://codecov.io/gh/radical-cybertools/radical.analytics/branch/devel/graph/badge.svg)](https://codecov.io/gh/radical-cybertools/radical.analytics)

[RADICAL-Analytics](https://github.com/radical-cybertools/radical.analytics) is a library supporting the analysis of data produced by the [RADICAL-Cybertools](https://radical-cybertools.github.io/). Currently, RADICAL-Analytics supports [RADICAL-Pilot (RP)](https://github.com/radical-cybertools/radical.pilot) and [RADICAl-EnsembleToolkit (EnTK)](https://github.com/radical-cybertools/radical.entk). RADICAL-Analytics supports the experimental analyses [published](http://radical.rutgers.edu/publications/) by the [RADICAL Group](http://radical.rutgers.edu/) at Rutgers University.

## Documentation
* General: https://radicalanalytics.readthedocs.io/en/latest/index.html
* API: https://radicalanalytics.readthedocs.io/en/latest/apidoc.html
